@@ -14,7 +14,7 @@ package org.jacoco.core.test.validation.targets;
 import static org.jacoco.core.test.validation.targets.Stubs.i1;
 
 /**
- * This test target is an interface with a class initializer.
+ * This test target is an interface with a class initializer and default methods.
  */
 public interface InterfaceDefaultMethodsTarget {
 
@@ -34,5 +34,9 @@ public interface InterfaceDefaultMethodsTarget {
 			m1();
 		}
 	}
+	
+	public static void main(String[] args) {
+		new Impl();
+	}
 
 }
